@@ -172,7 +172,7 @@ def compose_experiment(
     for key, setting in settings.items():
         if key in experiment_config_keys:
             experiment_config[key] = setting
-    return Engine(experiment_config)
+    return Engine(**experiment_config)
 
 
 # experiment loading functions
@@ -309,7 +309,7 @@ def composite_in_experiment(
     for key, setting in settings.items():
         if key in experiment_config_keys:
             experiment_config[key] = setting
-    return Engine(experiment_config)
+    return Engine(**experiment_config)
 
 
 def composer_in_experiment(
