@@ -107,9 +107,12 @@ updater_registry = Registry()
 #: Map divider names to :term:`divider` functions
 divider_registry = Registry()
 
-#: Map serializer names to divider :term:`serializer` classes
+#: Map serializer names to :term:`serializer` classes
 serializer_registry = Registry()
 
+#: Map serializer names to :term:`Emitter` classes
+emitter_registry = Registry()
+
 
 # Updaters, Dividers, and Serializers
 # These can be defined here, but are registered in the base module's __init__.py file
