@@ -6,8 +6,23 @@ from pint import Unit, UndefinedUnitError
 from pint.quantity import Quantity
 
 from vivarium.core.registry import serializer_registry
-from vivarium.core.composer import Composer
+from vivarium.core.composer import Composer, Composite
 from vivarium.core.process import Process
+from vivarium.library.dict_utils import remove_multi_update
+
+
+def composite_specification(
+        composite: Composite,
+        initial_state: bool = False,
+) -> dict:
+    composite_dict = serialize_value(composite)
+    composite_dict.pop('_schema')
+    if initial_state:
+        composite_initial_state = remove_multi_update(composite.initial_state())
+        composite_dict = dict(
+            composite_dict,
+            initial_state=composite_initial_state)
+    return composite_dict
 
 
 def serialize_value(value: Any) -> Any:
